diff src/os/unix/ngx_process_cycle.c @ 315:39b6f2df45c0

nginx-0.0.3-2004-04-14-21:44:28 import
author Igor Sysoev <igor@sysoev.ru>
date Wed, 14 Apr 2004 17:44:28 +0000
parents 11ff50a35d6d
children 1308b98496a2
line wrap: on
line diff
--- a/src/os/unix/ngx_process_cycle.c
+++ b/src/os/unix/ngx_process_cycle.c
@@ -82,13 +82,13 @@ void ngx_master_process_cycle(ngx_cycle_
 
             /*
              * we have to limit the maximum life time of the worker processes
              * by 1 month because our millisecond event timer is limited
              * by 49 days on 32-bit platforms
              */
 
             itv.it_interval.tv_sec = 0;
             itv.it_interval.tv_usec = 0;
-            itv.it_value.tv_sec = 30 * 24 * 60 * 60;
+            itv.it_value.tv_sec = 10 * 24 * 60 * 60;
             itv.it_value.tv_usec = 0;
 
             if (setitimer(ITIMER_REAL, &itv, NULL) == -1) {
@@ -82,13 +82,13 @@ void ngx_master_process_cycle(ngx_cycle_
             /*
              * we have to limit the maximum life time of the worker processes
-             * by 1 month because our millisecond event timer is limited
-             * by 49 days on 32-bit platforms
+             * by 10 days because our millisecond event timer is limited
+             * by 24 days on 32-bit platforms
              */
 